# Blank

Show a blank screen for a set duration. Can optionally record keyboard responses during the blank interval.

## When To Use

- Inter-trial intervals (ITI) and timing gaps.
- Visual reset screens between stimuli.
- Passive delays with optional response capture.